summaryrefslogtreecommitdiff
path: root/emacs
diff options
context:
space:
mode:
authorThien-Thi Nguyen <ttn@gnuvola.org>2001-11-19 06:59:38 +0000
committerThien-Thi Nguyen <ttn@gnuvola.org>2001-11-19 06:59:38 +0000
commitebc43ccb6dbe81fc861a76bffacea498f45b3794 (patch)
treebc0542ccd4462a31f07399c5cf18c76f409a6c31 /emacs
parent3faa54e7dd196be763fc21e159d93094ecdc4343 (diff)
downloadguile-ebc43ccb6dbe81fc861a76bffacea498f45b3794.tar.gz
(patch-send): Renamed from `patch-submit'.
Gadzooks what kind of world is this?
Diffstat (limited to 'emacs')
-rw-r--r--emacs/patch.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/emacs/patch.el b/emacs/patch.el
index e97c4231b..af8c45dfc 100644
--- a/emacs/patch.el
+++ b/emacs/patch.el
@@ -31,9 +31,9 @@
;; On the patch creation side of things, there are various version
;; control systems that are happy to write a diff to stdout (and
;; numerous Emacs interfaces to them all). Thus, we provide only a
-;; simple `patch-submit' that composes mail from the current buffer;
+;; simple `patch-send' that composes mail from the current buffer;
;; the contents of that buffer are left as an exercise for the patch
;; creator. When preparing the mail, `patch-submit' scans the patch
;; for standard filename headers and sets up a skeleton change log --
;; filling this in is a good way to earn respect from maintainers (hint
;; hint). Type `C-c C-c' to send the mail when you are done. (See
@@ -82,7 +82,7 @@
files
"\n")))
-(defun patch-submit (buffer subject)
+(defun patch-send (buffer subject)
(interactive "bBuffer: \nsSubject: ")
(when (string= "" subject)
(error "(empty subject)"))
@@ -31,9 +31,9 @@
;; the contents of that buffer are left as an exercise for the patch
-;; creator. When preparing the mail, `patch-submit' scans the patch
+;; creator. When preparing the mail, `patch-send' scans the patch
;; for standard filename headers and sets up a skeleton change log --
;; filling this in is a good way to earn respect from maintainers (hint